| Title: | Cosine Regression-Based Online Sliced Inverse Regression Algorithm |
|---|---|
| Description: | In high-dimensional streaming data analysis, extracting core periodic features under real-time constraints remains challenging. Traditional dimension reduction methods fail to adapt to incremental data and yield low accuracy due to irrelevant variables. This package provides the Online Sliced Inverse Regression framework for cosine regression with high-dimensional irrelevant variables. It integrates subspace extraction of sliced inverse regression and incremental learning of online algorithms to efficiently handle periodic streaming data. Cai, Z., Li, R., & Zhu, L. (2020) <doi:10.48550/arXiv.2002.02795>. |
| Authors: | Guangbao Guo [aut, cre], Sirui Yan [aut] |
| Maintainer: | Guangbao Guo <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.9 |
| Built: | 2026-05-29 09:59:05 UTC |
| Source: | https://github.com/cran/OSIRCR |
Batch SIR method. This method can estimate batch dimension reduction.
BSIR(data) bsir_batch_dataBSIR(data) bsir_batch_data
data |
is a highly correlated data set |
A data frame
Estimated central subspace
bsir_batch_data: bsir_batch_data
Example data for BSIR
BSIR(data=bsir_batch_data)BSIR(data=bsir_batch_data)
Online PCA method. This method can estimate online eigen space.
OPCA(data, m = 3) opca_online_dataOPCA(data, m = 3) opca_online_data
data |
is a highly correlated data set |
m |
is the number of principal component |
A data frame
Ahat, Dhat
opca_online_data: opca_online_data
Example data for OPCA
OPCA(data=opca_online_data,m=3)OPCA(data=opca_online_data,m=3)
OSIR Gradient Descent method. This method can estimate online dimension reduction.
OSIRgd(data) osir_gd_dataOSIRgd(data) osir_gd_data
data |
is a highly correlated data set |
A data frame
Estimated parameters and convergence result
osir_gd_data: osir_gd_data
Example data for OSIRgd
OSIRgd(data=osir_gd_data)OSIRgd(data=osir_gd_data)
OSIR Perturbation method. This method can estimate online dimension reduction.
OSIRpd(data) osir_pd_dataOSIRpd(data) osir_pd_data
data |
is a highly correlated data set |
A data frame
Estimated directions and error
osir_pd_data: osir_pd_data
Example data for OSIRpd
OSIRpd(data=osir_pd_data)OSIRpd(data=osir_pd_data)