| Type: | Package |
| Title: | Cosine Regression-Based Online Sliced Inverse Regression Algorithm |
| Version: | 0.2.9 |
| Author: | Guangbao Guo [aut, cre], Sirui Yan [aut] |
| Maintainer: | Guangbao Guo <ggb11111111@163.com> |
| Description: | In high-dimensional streaming data analysis, extracting core periodic features under real-time constraints remains challenging. Traditional dimension reduction methods fail to adapt to incremental data and yield low accuracy due to irrelevant variables. This package provides the Online Sliced Inverse Regression framework for cosine regression with high-dimensional irrelevant variables. It integrates subspace extraction of sliced inverse regression and incremental learning of online algorithms to efficiently handle periodic streaming data. Cai, Z., Li, R., & Zhu, L. (2020) <doi:10.48550/arXiv.2002.02795>. |
| License: | MIT + file LICENSE |
| Encoding: | UTF-8 |
| Depends: | R (≥ 3.5.0) |
| Imports: | stats |
| NeedsCompilation: | no |
| LazyData: | true |
| Packaged: | 2026-05-20 14:17:04 UTC; Lenovo |
| RoxygenNote: | 7.3.3 |
| Language: | en-US |
| Repository: | CRAN |
| Date/Publication: | 2026-05-28 11:10:28 UTC |
Batch SIR method. This method can estimate batch dimension reduction.
Description
Batch SIR method. This method can estimate batch dimension reduction.
Usage
BSIR(data)
bsir_batch_data
Arguments
data |
is a highly correlated data set |
Format
A data frame
Value
Estimated central subspace
Functions
-
bsir_batch_data: bsir_batch_data Example data for BSIR
Examples
BSIR(data=bsir_batch_data)
Online PCA method. This method can estimate online eigen space.
Description
Online PCA method. This method can estimate online eigen space.
Usage
OPCA(data, m = 3)
opca_online_data
Arguments
data |
is a highly correlated data set |
m |
is the number of principal component |
Format
A data frame
Value
Ahat, Dhat
Functions
-
opca_online_data: opca_online_data Example data for OPCA
Examples
OPCA(data=opca_online_data,m=3)
OSIR Gradient Descent method. This method can estimate online dimension reduction.
Description
OSIR Gradient Descent method. This method can estimate online dimension reduction.
Usage
OSIRgd(data)
osir_gd_data
Arguments
data |
is a highly correlated data set |
Format
A data frame
Value
Estimated parameters and convergence result
Functions
-
osir_gd_data: osir_gd_data Example data for OSIRgd
Examples
OSIRgd(data=osir_gd_data)
OSIR Perturbation method. This method can estimate online dimension reduction.
Description
OSIR Perturbation method. This method can estimate online dimension reduction.
Usage
OSIRpd(data)
osir_pd_data
Arguments
data |
is a highly correlated data set |
Format
A data frame
Value
Estimated directions and error
Functions
-
osir_pd_data: osir_pd_data Example data for OSIRpd
Examples
OSIRpd(data=osir_pd_data)